{
    "$graph": [
        {
            "label": "compute_gencode",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": "compute_gencode",
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-gencode"
                    },
                    "id": "#compute_gencode.cwl/gencode"
                },
                {
                    "type": "string",
                    "default": "gencode.txt",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#compute_gencode.cwl/output_impl"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-superkingdom"
                    },
                    "id": "#compute_gencode.cwl/superkingdom"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-taxid"
                    },
                    "id": "#compute_gencode.cwl/taxid"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-taxon-db"
                    },
                    "id": "#compute_gencode.cwl/taxon_db"
                }
            ],
            "id": "#compute_gencode.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_impl)"
                    },
                    "id": "#compute_gencode.cwl/output"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#file2int.cwl/input"
                }
            ],
            "expression": "${ return { \"value\": parseInt(inputs.input.contents) }; }\n",
            "outputs": [
                {
                    "type": "int",
                    "id": "#file2int.cwl/value"
                }
            ],
            "id": "#file2int.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Filter Protein Alignments",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "align_filter",
            "arguments": [
                "-filter",
                "pct_identity_gapopen_only >= 50 AND ( (query_start<=20 AND SUB(query_length, query_end)<=20) OR pct_identity_gapopen_only >= 60 ) AND (SUB(subject_end, subject_start) > 90 || SUB(subject_end, subject_start) > MUL(query_length,1.5) || num_ident >=60) AND (query_length > 30 || (pct_identity_gapopen_only >= 80 AND SUB(subject_end, subject_start) >= MUL(query_length,2.4)))",
                "-ifmt",
                "seq-align",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#align_filter.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#align_filter.cwl/file_in"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#align_filter.cwl/output"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align-nomatch.asn",
                    "inputBinding": {
                        "prefix": "-non-match-output"
                    },
                    "id": "#align_filter.cwl/output_non_match"
                },
                {
                    "type": "Directory",
                    "id": "#align_filter.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#align_filter.cwl/align"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_non_match)"
                    },
                    "id": "#align_filter.cwl/align_non_match"
                }
            ],
            "id": "#align_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sort Seed Hits, align_sort",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "align_sort",
            "arguments": [
                "-ifmt",
                "seq-align-set",
                "-k",
                "query,subject",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#align_sort.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#align_sort.cwl/blast_aligns"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-limit-mem"
                    },
                    "id": "#align_sort.cwl/limit_mem"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#align_sort.cwl/output"
                },
                {
                    "type": "Directory",
                    "id": "#align_sort.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#align_sort.cwl/sorted_aligns"
                }
            ],
            "id": "#align_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Filter Full-Coverage Alignments",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMax": 8000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "bacterial_protalign_filter",
            "arguments": [
                "-filter-accept",
                "pct_coverage = 100 AND qframe = 0 AND sframe = 0 AND cds_internal_stops = 0",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#bacterial_protalign_filter.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align_full_cov.asn",
                    "inputBinding": {
                        "prefix": "-ofull"
                    },
                    "id": "#bacterial_protalign_filter.cwl/full_output"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align_partial_cov.asn",
                    "inputBinding": {
                        "prefix": "-opartial"
                    },
                    "id": "#bacterial_protalign_filter.cwl/part_output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#bacterial_protalign_filter.cwl/sorted_seeds"
                },
                {
                    "type": "Directory",
                    "id": "#bacterial_protalign_filter.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.full_output)"
                    },
                    "id": "#bacterial_protalign_filter.cwl/blast_full_cov"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.part_output)"
                    },
                    "id": "#bacterial_protalign_filter.cwl/blast_partial_cov"
                }
            ],
            "id": "#bacterial_protalign_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "file concatenation",
            "baseCommand": "cat",
            "stdout": "out.asn",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat.cwl/file_in_1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cat.cwl/file_in_2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat.cwl/file_out",
                    "outputBinding": {
                        "glob": "out.asn"
                    }
                }
            ],
            "id": "#cat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Seed Protein Alignments, gather",
            "baseCommand": "gpx_make_outputs",
            "arguments": [
                "-unzip",
                "*",
                "-num-partitions",
                "1"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_make_outputs.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "blast.#.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_make_outputs.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "blast.*.asn"
                    },
                    "id": "#gpx_make_outputs.cwl/blast_align"
                }
            ],
            "id": "#gpx_make_outputs.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Seed Search Compartments, gather",
            "baseCommand": "gpx_qdump",
            "arguments": [
                "-unzip",
                "*",
                "-produce-empty-file"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_qdump.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "blast.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qdump.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#gpx_qdump.cwl/seed_align"
                }
            ],
            "id": "#gpx_qdump.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Find ProSplign Alignments, gather",
            "baseCommand": "gpx_qdump",
            "arguments": [
                "-unzip",
                "*"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_qdump_pro.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "prosplign.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qdump_pro.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#gpx_qdump_pro.cwl/prosplign_align"
                }
            ],
            "id": "#gpx_qdump_pro.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Seed Search Compartments, scatter",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "arguments": [
                "-affinity",
                "subject",
                "-batch-size",
                "1",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-asn"
                    },
                    "id": "#gpx_qsubmit.cwl/asn"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#gpx_qsubmit.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qsubmit.cwl/output"
                },
                {
                    "type": "Directory",
                    "id": "#gpx_qsubmit.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#gpx_qsubmit.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Seed Protein Alignments, scatter",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "arguments": [
                "-affinity",
                "subject",
                "-max-batch-length",
                "10000",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#gpx_qsubmit_1.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "blastdb",
                    "inputBinding": {
                        "prefix": "-db",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#gpx_qsubmit_1.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#gpx_qsubmit_1.cwl/blastdb_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qsubmit_1.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-ids"
                    },
                    "id": "#gpx_qsubmit_1.cwl/seqids"
                },
                {
                    "type": "Directory",
                    "id": "#gpx_qsubmit_1.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#gpx_qsubmit_1.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit_1.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Find ProSplign Alignments, scatter",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "arguments": [
                "-NxM-threshold",
                "10000",
                "-affinity",
                "subject",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-asn"
                    },
                    "id": "#gpx_qsubmit_pro.cwl/asn"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#gpx_qsubmit_pro.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qsubmit_pro.cwl/output"
                },
                {
                    "type": "Directory",
                    "id": "#gpx_qsubmit_pro.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#gpx_qsubmit_pro.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit_pro.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Filter Protein Seeds, compart",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMax": 15000
                }
            ],
            "baseCommand": "prosplign_compart",
            "arguments": [
                "-compartment_penalty",
                "0.10",
                "-max_extent",
                "100",
                "-max_intron",
                "100",
                "-maximize",
                "coverage",
                "-min_compartment_idty",
                "0.05",
                "-min_singleton_idty",
                "0.05",
                "-nogenbank",
                "-prosplign-gaps",
                "-ifmt",
                "seq-align"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#prosplign_compart.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "unfiltered_compartments.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#prosplign_compart.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#prosplign_compart.cwl/seed_hits"
                },
                {
                    "type": "Directory",
                    "id": "#prosplign_compart.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#prosplign_compart.cwl/unfilt_comp"
                }
            ],
            "id": "#prosplign_compart.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Filter Protein Seeds, compart filter",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "prosplign_compart_filter",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#prosplign_compart_filter.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-gc-assembly"
                    },
                    "id": "#prosplign_compart_filter.cwl/gc_assembly"
                },
                {
                    "type": "int",
                    "default": 5000,
                    "inputBinding": {
                        "prefix": "-max_compart_count"
                    },
                    "id": "#prosplign_compart_filter.cwl/max_compart_count"
                },
                {
                    "type": "float",
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "-min_prot_coverage"
                    },
                    "id": "#prosplign_compart_filter.cwl/min_prot_coverage"
                },
                {
                    "type": "float",
                    "default": 0.5,
                    "inputBinding": {
                        "prefix": "-min_scaffold_coverage"
                    },
                    "id": "#prosplign_compart_filter.cwl/min_scaffold_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "-nogenbank"
                    },
                    "id": "#prosplign_compart_filter.cwl/nogenbank"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "compartments.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#prosplign_compart_filter.cwl/output"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-sufficient_compart_length"
                    },
                    "id": "#prosplign_compart_filter.cwl/sufficient_compart_length"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#prosplign_compart_filter.cwl/unfilt_comp"
                },
                {
                    "type": "Directory",
                    "id": "#prosplign_compart_filter.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#prosplign_compart_filter.cwl/compartments"
                }
            ],
            "id": "#prosplign_compart_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Seed Search Compartments, execute\"",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMax": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "prosplign_wnode",
            "arguments": [
                "-compartment_penalty",
                "0.10",
                "-cut_flank_partial_codons",
                "true",
                "-cut_flanks_with_posit_drop",
                "true",
                "-cut_flanks_with_posit_dropoff",
                "40",
                "-cut_flanks_with_posit_gap_ratio",
                "18",
                "-cut_flanks_with_posit_max_len",
                "48",
                "-cut_flanks_with_posit_window",
                "150",
                "-fill_holes",
                "true",
                "-flank_positives",
                "49",
                "-frameshift_opening",
                "30",
                "-gap_extension",
                "1",
                "-gap_opening",
                "10",
                "-intron_AT",
                "25",
                "-intron_GC",
                "20",
                "-intron_GT",
                "15",
                "-intron_non_consensus",
                "34",
                "-inverted_intron_extension",
                "1000",
                "-max_bad_len",
                "45",
                "-max_extent",
                "100",
                "-max_intron",
                "100",
                "-max_overlap",
                "60",
                "-maximize",
                "coverage",
                "-min-jobs",
                "5",
                "-min_compartment_idty",
                "0.05",
                "-min_exon_ident",
                "30",
                "-min_exon_positives",
                "55",
                "-min_flanking_exon_len",
                "41",
                "-min_good_len",
                "41",
                "-min_intron_len",
                "30",
                "-min_positives",
                "15",
                "-min_singleton_idty",
                "0.05",
                "-score_matrix",
                "BLOSUM62",
                "-start_bonus",
                "8",
                "-stop_bonus",
                "8",
                "-total_positives",
                "55",
                "-allow_alt_starts",
                "-no_introns",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-file"
                    },
                    "id": "#prosplign_wnode.cwl/asn"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#prosplign_wnode.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#prosplign_wnode.cwl/input_jobs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#prosplign_wnode.cwl/output_dir"
                },
                {
                    "type": "Directory",
                    "id": "#prosplign_wnode.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#prosplign_wnode.cwl/outdir"
                }
            ],
            "id": "#prosplign_wnode.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Seed Search Compartments, execute\"",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMax": 3000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "tblastn_wnode",
            "arguments": [
                "-comp_based_stats",
                "F",
                "-dbsize",
                "6000000000",
                "-delay",
                "0",
                "-evalue",
                "0.1",
                "-gapextend",
                "2",
                "-gapopen",
                "9",
                "-matrix",
                "BLOSUM62",
                "-seg",
                "no",
                "-soft_masking",
                "true",
                "-threshold",
                "12",
                "-word_size",
                "3",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-file"
                    },
                    "id": "#tblastn_wnode.cwl/asn"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#tblastn_wnode.cwl/asn_cache"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-db_gencode"
                    },
                    "id": "#tblastn_wnode.cwl/db_gencode"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#tblastn_wnode.cwl/input_jobs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#tblastn_wnode.cwl/output_dir"
                },
                {
                    "type": "Directory",
                    "id": "#tblastn_wnode.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#tblastn_wnode.cwl/outdir"
                }
            ],
            "id": "#tblastn_wnode.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Seed Protein Alignments, execute",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMax": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "tblastn_wnode",
            "arguments": [
                "-align_filter",
                "pct_identity_gapopen_only >= 75",
                "-backlog",
                "1",
                "-comp_based_stats",
                "F",
                "-dbsize",
                "6000000000",
                "-delay",
                "0",
                "-evalue",
                "0.1",
                "-gapextend",
                "2",
                "-gapopen",
                "9",
                "-matrix",
                "BLOSUM62",
                "-max-jobs",
                "1",
                "-seg",
                "no",
                "-soft_masking",
                "true",
                "-threshold",
                "21",
                "-word_size",
                "6",
                "-nogenbank",
                "-short-protein-threshold",
                "30"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#tblastn_wnode_1.cwl/asn_cache"
                },
                {
                    "type": "Directory",
                    "id": "#tblastn_wnode_1.cwl/blastdb_dir"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-db_gencode"
                    },
                    "id": "#tblastn_wnode_1.cwl/db_gencode"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#tblastn_wnode_1.cwl/input_jobs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#tblastn_wnode_1.cwl/output_dir"
                },
                {
                    "type": "Directory",
                    "id": "#tblastn_wnode_1.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#tblastn_wnode_1.cwl/outdir"
                }
            ],
            "id": "#tblastn_wnode_1.cwl"
        },
        {
            "class": "Workflow",
            "label": "Filter Protein Alignments",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#wf_align_filter.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "id": "#wf_align_filter.cwl/blast_full"
                },
                {
                    "type": "File",
                    "id": "#wf_align_filter.cwl/prosplign"
                },
                {
                    "type": "Directory",
                    "id": "#wf_align_filter.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_align_filter.cwl/align_filter/align",
                    "id": "#wf_align_filter.cwl/align"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_align_filter.cwl/align_filter/align_non_match",
                    "id": "#wf_align_filter.cwl/align_non_match"
                }
            ],
            "steps": [
                {
                    "run": "#align_filter.cwl",
                    "in": [
                        {
                            "source": "#wf_align_filter.cwl/asn_cache",
                            "id": "#wf_align_filter.cwl/align_filter/asn_cache"
                        },
                        {
                            "source": "#wf_align_filter.cwl/cat/file_out",
                            "id": "#wf_align_filter.cwl/align_filter/file_in"
                        },
                        {
                            "source": "#wf_align_filter.cwl/uniColl_asn_cache",
                            "id": "#wf_align_filter.cwl/align_filter/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_align_filter.cwl/align_filter/align",
                        "#wf_align_filter.cwl/align_filter/align_non_match"
                    ],
                    "id": "#wf_align_filter.cwl/align_filter"
                },
                {
                    "run": "#cat.cwl",
                    "in": [
                        {
                            "source": "#wf_align_filter.cwl/blast_full",
                            "id": "#wf_align_filter.cwl/cat/file_in_1"
                        },
                        {
                            "source": "#wf_align_filter.cwl/prosplign",
                            "id": "#wf_align_filter.cwl/cat/file_in_2"
                        }
                    ],
                    "out": [
                        "#wf_align_filter.cwl/cat/file_out"
                    ],
                    "id": "#wf_align_filter.cwl/cat"
                }
            ],
            "id": "#wf_align_filter.cwl"
        },
        {
            "class": "Workflow",
            "label": "Filter Protein Seeds; Find ProSplign Alignments",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#wf_compart_filter_prosplign.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "id": "#wf_compart_filter_prosplign.cwl/gc_assembly"
                },
                {
                    "type": "File",
                    "id": "#wf_compart_filter_prosplign.cwl/seed_hits"
                },
                {
                    "type": "Directory",
                    "id": "#wf_compart_filter_prosplign.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qdump/prosplign_align",
                    "id": "#wf_compart_filter_prosplign.cwl/prosplign_align"
                }
            ],
            "steps": [
                {
                    "run": "#prosplign_compart.cwl",
                    "in": [
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/asn_cache",
                            "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart/asn_cache"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/seed_hits",
                            "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart/seed_hits"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/uniColl_asn_cache",
                            "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart/unfilt_comp"
                    ],
                    "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart"
                },
                {
                    "run": "#prosplign_compart_filter.cwl",
                    "in": [
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/asn_cache",
                            "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter/asn_cache"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/gc_assembly",
                            "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter/gc_assembly"
                        },
                        {
                            "default": 1500,
                            "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter/sufficient_compart_length"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart/unfilt_comp",
                            "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter/unfilt_comp"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/uniColl_asn_cache",
                            "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter/compartments"
                    ],
                    "id": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter"
                },
                {
                    "run": "#gpx_qdump_pro.cwl",
                    "in": [
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_prosplign_wnode/outdir",
                            "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qdump/input_path"
                        }
                    ],
                    "out": [
                        "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qdump/prosplign_align"
                    ],
                    "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qdump"
                },
                {
                    "run": "#gpx_qsubmit_pro.cwl",
                    "in": [
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter/compartments",
                            "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qsubmit/asn"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/asn_cache",
                            "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qsubmit/asn_cache"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/uniColl_asn_cache",
                            "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qsubmit/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qsubmit/jobs"
                    ],
                    "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qsubmit"
                },
                {
                    "run": "#prosplign_wnode.cwl",
                    "in": [
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/Filter_Protein_Seeds_prosplign_compart_filter/compartments",
                            "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_prosplign_wnode/asn"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/asn_cache",
                            "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_prosplign_wnode/asn_cache"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_gpx_qsubmit/jobs",
                            "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_prosplign_wnode/input_jobs"
                        },
                        {
                            "source": "#wf_compart_filter_prosplign.cwl/uniColl_asn_cache",
                            "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_prosplign_wnode/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_prosplign_wnode/outdir"
                    ],
                    "id": "#wf_compart_filter_prosplign.cwl/Find_ProSplign_Alignments_prosplign_wnode"
                }
            ],
            "id": "#wf_compart_filter_prosplign.cwl"
        },
        {
            "class": "Workflow",
            "label": "Align reference proteins plane complete workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/all_prots"
                },
                {
                    "type": "Directory",
                    "id": "#main/asn_cache"
                },
                {
                    "type": "Directory",
                    "id": "#main/blastdb_dir"
                },
                {
                    "type": "File",
                    "id": "#main/compartments"
                },
                {
                    "type": "File",
                    "id": "#main/gc_assembly"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "boolean"
                    },
                    "id": "#main/go"
                },
                {
                    "type": "File",
                    "id": "#main/tax_sql_file"
                },
                {
                    "type": "int",
                    "id": "#main/taxid"
                },
                {
                    "type": "Directory",
                    "id": "#main/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/Filter_Protein_Alignments/align",
                    "id": "#main/align"
                },
                {
                    "type": "File",
                    "outputSource": "#main/Filter_Protein_Alignments/align_non_match",
                    "id": "#main/align_non_match"
                }
            ],
            "steps": [
                {
                    "run": "#compute_gencode.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/Compute_Gencode/gencode"
                        },
                        {
                            "source": "#main/taxid",
                            "id": "#main/Compute_Gencode/taxid"
                        },
                        {
                            "source": "#main/tax_sql_file",
                            "id": "#main/Compute_Gencode/taxon_db"
                        }
                    ],
                    "out": [
                        "#main/Compute_Gencode/output"
                    ],
                    "id": "#main/Compute_Gencode"
                },
                {
                    "run": "#file2int.cwl",
                    "in": [
                        {
                            "source": "#main/Compute_Gencode/output",
                            "id": "#main/Compute_Gencode_int/input"
                        }
                    ],
                    "out": [
                        "#main/Compute_Gencode_int/value"
                    ],
                    "id": "#main/Compute_Gencode_int"
                },
                {
                    "run": "#bacterial_protalign_filter.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/Filter_Full_Coverage_Alignments/asn_cache"
                        },
                        {
                            "source": "#main/Sort_Seed_Hits/sorted_aligns",
                            "id": "#main/Filter_Full_Coverage_Alignments/sorted_seeds"
                        },
                        {
                            "source": "#main/uniColl_asn_cache",
                            "id": "#main/Filter_Full_Coverage_Alignments/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#main/Filter_Full_Coverage_Alignments/blast_full_cov",
                        "#main/Filter_Full_Coverage_Alignments/blast_partial_cov"
                    ],
                    "id": "#main/Filter_Full_Coverage_Alignments"
                },
                {
                    "run": "#wf_align_filter.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/Filter_Protein_Alignments/asn_cache"
                        },
                        {
                            "source": "#main/Filter_Full_Coverage_Alignments/blast_full_cov",
                            "id": "#main/Filter_Protein_Alignments/blast_full"
                        },
                        {
                            "source": "#main/compart_filter_prosplign/prosplign_align",
                            "id": "#main/Filter_Protein_Alignments/prosplign"
                        },
                        {
                            "source": "#main/uniColl_asn_cache",
                            "id": "#main/Filter_Protein_Alignments/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#main/Filter_Protein_Alignments/align",
                        "#main/Filter_Protein_Alignments/align_non_match"
                    ],
                    "id": "#main/Filter_Protein_Alignments"
                },
                {
                    "run": "#wf_seed_1.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/Seed_Protein_Alignments/asn_cache"
                        },
                        {
                            "source": "#main/blastdb_dir",
                            "id": "#main/Seed_Protein_Alignments/blastdb_dir"
                        },
                        {
                            "source": "#main/Compute_Gencode_int/value",
                            "id": "#main/Seed_Protein_Alignments/db_gencode"
                        },
                        {
                            "source": "#main/all_prots",
                            "id": "#main/Seed_Protein_Alignments/seqids"
                        },
                        {
                            "source": "#main/uniColl_asn_cache",
                            "id": "#main/Seed_Protein_Alignments/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#main/Seed_Protein_Alignments/blast_align"
                    ],
                    "id": "#main/Seed_Protein_Alignments"
                },
                {
                    "run": "#wf_seed.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/Seed_Search_Compartments/asn_cache"
                        },
                        {
                            "source": "#main/compartments",
                            "id": "#main/Seed_Search_Compartments/compartments"
                        },
                        {
                            "source": "#main/Compute_Gencode_int/value",
                            "id": "#main/Seed_Search_Compartments/db_gencode"
                        },
                        {
                            "source": "#main/uniColl_asn_cache",
                            "id": "#main/Seed_Search_Compartments/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#main/Seed_Search_Compartments/blast_align"
                    ],
                    "id": "#main/Seed_Search_Compartments"
                },
                {
                    "run": "#align_sort.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/Sort_Seed_Hits/asn_cache"
                        },
                        {
                            "source": "#main/cat/file_out",
                            "id": "#main/Sort_Seed_Hits/blast_aligns"
                        },
                        {
                            "default": "1G",
                            "id": "#main/Sort_Seed_Hits/limit_mem"
                        },
                        {
                            "source": "#main/uniColl_asn_cache",
                            "id": "#main/Sort_Seed_Hits/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#main/Sort_Seed_Hits/sorted_aligns"
                    ],
                    "id": "#main/Sort_Seed_Hits"
                },
                {
                    "run": "#cat.cwl",
                    "in": [
                        {
                            "source": "#main/Seed_Protein_Alignments/blast_align",
                            "id": "#main/cat/file_in_1"
                        },
                        {
                            "source": "#main/Seed_Search_Compartments/blast_align",
                            "id": "#main/cat/file_in_2"
                        }
                    ],
                    "out": [
                        "#main/cat/file_out"
                    ],
                    "id": "#main/cat"
                },
                {
                    "run": "#wf_compart_filter_prosplign.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/compart_filter_prosplign/asn_cache"
                        },
                        {
                            "source": "#main/gc_assembly",
                            "id": "#main/compart_filter_prosplign/gc_assembly"
                        },
                        {
                            "source": "#main/Filter_Full_Coverage_Alignments/blast_partial_cov",
                            "id": "#main/compart_filter_prosplign/seed_hits"
                        },
                        {
                            "source": "#main/uniColl_asn_cache",
                            "id": "#main/compart_filter_prosplign/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#main/compart_filter_prosplign/prosplign_align"
                    ],
                    "id": "#main/compart_filter_prosplign"
                }
            ],
            "id": "#main"
        },
        {
            "class": "Workflow",
            "label": "Seed Search Compartments",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#wf_seed.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "id": "#wf_seed.cwl/compartments"
                },
                {
                    "type": "int",
                    "id": "#wf_seed.cwl/db_gencode"
                },
                {
                    "type": "Directory",
                    "id": "#wf_seed.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_seed.cwl/gpx_dump/seed_align",
                    "id": "#wf_seed.cwl/blast_align"
                }
            ],
            "steps": [
                {
                    "run": "#gpx_qdump.cwl",
                    "in": [
                        {
                            "source": "#wf_seed.cwl/tblastn_wnode/outdir",
                            "id": "#wf_seed.cwl/gpx_dump/input_path"
                        }
                    ],
                    "out": [
                        "#wf_seed.cwl/gpx_dump/seed_align"
                    ],
                    "id": "#wf_seed.cwl/gpx_dump"
                },
                {
                    "run": "#gpx_qsubmit.cwl",
                    "in": [
                        {
                            "source": "#wf_seed.cwl/compartments",
                            "id": "#wf_seed.cwl/gpx_qsubmit/asn"
                        },
                        {
                            "source": "#wf_seed.cwl/asn_cache",
                            "id": "#wf_seed.cwl/gpx_qsubmit/asn_cache"
                        },
                        {
                            "source": "#wf_seed.cwl/uniColl_asn_cache",
                            "id": "#wf_seed.cwl/gpx_qsubmit/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_seed.cwl/gpx_qsubmit/jobs"
                    ],
                    "id": "#wf_seed.cwl/gpx_qsubmit"
                },
                {
                    "run": "#tblastn_wnode.cwl",
                    "in": [
                        {
                            "source": "#wf_seed.cwl/compartments",
                            "id": "#wf_seed.cwl/tblastn_wnode/asn"
                        },
                        {
                            "source": "#wf_seed.cwl/asn_cache",
                            "id": "#wf_seed.cwl/tblastn_wnode/asn_cache"
                        },
                        {
                            "source": "#wf_seed.cwl/db_gencode",
                            "id": "#wf_seed.cwl/tblastn_wnode/db_gencode"
                        },
                        {
                            "source": "#wf_seed.cwl/gpx_qsubmit/jobs",
                            "id": "#wf_seed.cwl/tblastn_wnode/input_jobs"
                        },
                        {
                            "source": "#wf_seed.cwl/uniColl_asn_cache",
                            "id": "#wf_seed.cwl/tblastn_wnode/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_seed.cwl/tblastn_wnode/outdir"
                    ],
                    "id": "#wf_seed.cwl/tblastn_wnode"
                }
            ],
            "id": "#wf_seed.cwl"
        },
        {
            "class": "Workflow",
            "label": "Seed Protein Alignments",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#wf_seed_1.cwl/asn_cache"
                },
                {
                    "type": "Directory",
                    "id": "#wf_seed_1.cwl/blastdb_dir"
                },
                {
                    "type": "int",
                    "id": "#wf_seed_1.cwl/db_gencode"
                },
                {
                    "type": "File",
                    "id": "#wf_seed_1.cwl/seqids"
                },
                {
                    "type": "Directory",
                    "id": "#wf_seed_1.cwl/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_seed_1.cwl/gpx_make_outputs/blast_align",
                    "id": "#wf_seed_1.cwl/blast_align"
                }
            ],
            "steps": [
                {
                    "run": "#gpx_make_outputs.cwl",
                    "in": [
                        {
                            "source": "#wf_seed_1.cwl/tblastn_wnode/outdir",
                            "id": "#wf_seed_1.cwl/gpx_make_outputs/input_path"
                        }
                    ],
                    "out": [
                        "#wf_seed_1.cwl/gpx_make_outputs/blast_align"
                    ],
                    "id": "#wf_seed_1.cwl/gpx_make_outputs"
                },
                {
                    "run": "#gpx_qsubmit_1.cwl",
                    "in": [
                        {
                            "source": "#wf_seed_1.cwl/asn_cache",
                            "id": "#wf_seed_1.cwl/gpx_qsubmit/asn_cache"
                        },
                        {
                            "source": "#wf_seed_1.cwl/blastdb_dir",
                            "id": "#wf_seed_1.cwl/gpx_qsubmit/blastdb_dir"
                        },
                        {
                            "source": "#wf_seed_1.cwl/seqids",
                            "id": "#wf_seed_1.cwl/gpx_qsubmit/seqids"
                        },
                        {
                            "source": "#wf_seed_1.cwl/uniColl_asn_cache",
                            "id": "#wf_seed_1.cwl/gpx_qsubmit/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_seed_1.cwl/gpx_qsubmit/jobs"
                    ],
                    "id": "#wf_seed_1.cwl/gpx_qsubmit"
                },
                {
                    "run": "#tblastn_wnode_1.cwl",
                    "in": [
                        {
                            "source": "#wf_seed_1.cwl/asn_cache",
                            "id": "#wf_seed_1.cwl/tblastn_wnode/asn_cache"
                        },
                        {
                            "source": "#wf_seed_1.cwl/blastdb_dir",
                            "id": "#wf_seed_1.cwl/tblastn_wnode/blastdb_dir"
                        },
                        {
                            "source": "#wf_seed_1.cwl/db_gencode",
                            "id": "#wf_seed_1.cwl/tblastn_wnode/db_gencode"
                        },
                        {
                            "source": "#wf_seed_1.cwl/gpx_qsubmit/jobs",
                            "id": "#wf_seed_1.cwl/tblastn_wnode/input_jobs"
                        },
                        {
                            "source": "#wf_seed_1.cwl/uniColl_asn_cache",
                            "id": "#wf_seed_1.cwl/tblastn_wnode/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#wf_seed_1.cwl/tblastn_wnode/outdir"
                    ],
                    "id": "#wf_seed_1.cwl/tblastn_wnode"
                }
            ],
            "id": "#wf_seed_1.cwl"
        }
    ],
    "cwlVersion": "v1.2"
}
